==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/MagazynOperacja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypMagazynu;
import pl.topteam.dps.enums.TypOperacjiWMagazynie;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class MagazynOperacja extends GenericDPSObject {
    /**
     * MAGAZYN_OPERACJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * MAGAZYN_OPERACJA.MAGAZYN_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypMagazynu magazynId;

    /**
     * MAGAZYN_OPERACJA.SLOWO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slowoId;

    /**
     * MAGAZYN_OPERACJA.OBIEKT_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long obiektId;

    /**
     * MAGAZYN_OPERACJA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * MAGAZYN_OPERACJA.ILOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal ilosc;

    /**
     * MAGAZYN_OPERACJA.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypOperacjiWMagazynie typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MAGAZYN_OPERACJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * MAGAZYN_OPERACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return MAGAZYN_OPERACJA.MAGAZYN_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypMagazynu getMagazynId() {
        return magazynId;
    }

    /**
     * MAGAZYN_OPERACJA.MAGAZYN_ID
     *
     * @param magazynId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMagazynId(TypMagazynu magazynId) {
        this.magazynId = magazynId;
    }

    /**
     * @return MAGAZYN_OPERACJA.SLOWO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * MAGAZYN_OPERACJA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return MAGAZYN_OPERACJA.OBIEKT_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getObiektId() {
        return obiektId;
    }

    /**
     * MAGAZYN_OPERACJA.OBIEKT_ID
     *
     * @param obiektId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setObiektId(Long obiektId) {
        this.obiektId = obiektId;
    }

    /**
     * @return MAGAZYN_OPERACJA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * MAGAZYN_OPERACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return MAGAZYN_OPERACJA.ILOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getIlosc() {
        return ilosc;
    }

    /**
     * MAGAZYN_OPERACJA.ILOSC
     *
     * @param ilosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setIlosc(BigDecimal ilosc) {
        this.ilosc = ilosc;
    }

    /**
     * @return MAGAZYN_OPERACJA.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypOperacjiWMagazynie getTyp() {
        return typ;
    }

    /**
     * MAGAZYN_OPERACJA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypOperacjiWMagazynie typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        MagazynOperacja other = (MagazynOperacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getMagazynId() == null ? other.getMagazynId() == null : this.getMagazynId().equals(other.getMagazynId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getObiektId() == null ? other.getObiektId() == null : this.getObiektId().equals(other.getObiektId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getIlosc() == null ? other.getIlosc() == null : this.getIlosc().equals(other.getIlosc()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getMagazynId() == null) ? 0 : getMagazynId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getObiektId() == null) ? 0 : getObiektId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getIlosc() == null) ? 0 : getIlosc().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", magazynId=").append(magazynId);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", obiektId=").append(obiektId);
        sb.append(", data=").append(data);
        sb.append(", ilosc=").append(ilosc);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/MagazynOperacja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypMagazynu;
import pl.topteam.dps.enums.TypOperacjiWMagazynie;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class MagazynOperacja extends GenericDPSObject {
    /**
     * MAGAZYN_OPERACJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * MAGAZYN_OPERACJA.MAGAZYN_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypMagazynu magazynId;

    /**
     * MAGAZYN_OPERACJA.SLOWO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slowoId;

    /**
     * MAGAZYN_OPERACJA.OBIEKT_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long obiektId;

    /**
     * MAGAZYN_OPERACJA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * MAGAZYN_OPERACJA.ILOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal ilosc;

    /**
     * MAGAZYN_OPERACJA.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypOperacjiWMagazynie typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MAGAZYN_OPERACJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * MAGAZYN_OPERACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * MAGAZYN_OPERACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return MAGAZYN_OPERACJA.MAGAZYN_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypMagazynu getMagazynId() {
        return magazynId;
    }

    /**
     * MAGAZYN_OPERACJA.MAGAZYN_ID
     *
     * @param magazynId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMagazynId(TypMagazynu magazynId) {
        this.magazynId = magazynId;
    }

    /**
     * @return MAGAZYN_OPERACJA.SLOWO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * MAGAZYN_OPERACJA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return MAGAZYN_OPERACJA.OBIEKT_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getObiektId() {
        return obiektId;
    }

    /**
     * MAGAZYN_OPERACJA.OBIEKT_ID
     *
     * @param obiektId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setObiektId(Long obiektId) {
        this.obiektId = obiektId;
    }

    /**
     * @return MAGAZYN_OPERACJA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * MAGAZYN_OPERACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return MAGAZYN_OPERACJA.ILOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getIlosc() {
        return ilosc;
    }

    /**
     * MAGAZYN_OPERACJA.ILOSC
     *
     * @param ilosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setIlosc(BigDecimal ilosc) {
        this.ilosc = ilosc;
    }

    /**
     * @return MAGAZYN_OPERACJA.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypOperacjiWMagazynie getTyp() {
        return typ;
    }

    /**
     * MAGAZYN_OPERACJA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypOperacjiWMagazynie typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        MagazynOperacja other = (MagazynOperacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getMagazynId() == null ? other.getMagazynId() == null : this.getMagazynId().equals(other.getMagazynId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getObiektId() == null ? other.getObiektId() == null : this.getObiektId().equals(other.getObiektId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getIlosc() == null ? other.getIlosc() == null : this.getIlosc().equals(other.getIlosc()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getMagazynId() == null) ? 0 : getMagazynId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getObiektId() == null) ? 0 : getObiektId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getIlosc() == null) ? 0 : getIlosc().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", magazynId=").append(magazynId);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", obiektId=").append(obiektId);
        sb.append(", data=").append(data);
        sb.append(", ilosc=").append(ilosc);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
